/*
 *  libmodem library, a modem control facility.
 *
 *  modems.h.in - main header file of the libmodem package
 *
 *  Copyright (C) 1994,1995,1996,1997,1998,1999  Riccardo Facchetti
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  You can contact the author at this e-mail address:
 *
 *  fizban@tin.it
 */

/*
 * avoid multiple inclusion
 */
#ifndef _LM_MODEMS_H
#define _LM_MODEMS_H 1

/*
 * standard includes needed for the headers to work
 */
#include <sys/types.h>

/*
 * Some useful defines
 */
#ifndef MAXNAMLEN
#define MAXNAMLEN    255
#endif /* MAXNAMLEN */

#ifndef FAILURE
#define FAILURE        0
#endif /* FAILURE */

#ifndef SUCCESS
#define SUCCESS        1
#endif /* SUCCESS */

#define LIBMODEM_VER    "1.5"

#include <dial/mdmerrno.h>

/*
 * MDMFILE: the standard system modems description file
 */
#define MDMFILE        "/etc/modems"

/*
 * LOCKDIR: the locks directory
 */
#define LOCKDIR			"/var/lock/"

#ifndef LOCKDIR
# ifndef linux
#  define LOCKDIR		"/var/spool/locks"
# else
#  define LOCKDIR		"/var/lock"
# endif
#endif /* LOCKDIR */

/*
 * This is the include file related to /etc/modems file.
 */

/*
 * This is the maximum lenght of modem commands into /etc/modems structure.
 */
#define MAXMDMCMD	64

/*
 * Flow control values in /etc/modems
 */
#define FLOW_HARD        0
#define FLOW_XON_XOFF    1

#if !defined(__BEGIN_DECLS) && !defined(__END_DECLS)
/*
 * This is GNU libc macros for extern C functions: just in case.
 *
 * C++ needs to know that types and declarations are C, not C++.
 */
# ifdef  __cplusplus
#  define __BEGIN_DECLS  extern "C" {
#  define __END_DECLS    }
# else
#  define __BEGIN_DECLS
#  define __END_DECLS
# endif
#endif

struct modems {
    char line[MAXNAMLEN];      /* line name (without /dev/) */
    char cp[MAXMDMCMD];        /* command prefix */
    char ce[MAXMDMCMD];        /* command end */
    char at[MAXMDMCMD];        /* attention string */
    time_t    dl;              /* delay waiting answer from modem */
    int bdi;                   /* max baud rate (integer number) */
    int bd;                    /* max baud rate (termios translation) */
    char cs[MAXMDMCMD];        /* connect string */
    char ds[MAXMDMCMD];        /* dial string */
    char dp[MAXMDMCMD];        /* dial prefix */
    char de[MAXMDMCMD];        /* dial end */
    char im[MAXMDMCMD];        /* initialize modem */
    char hu[MAXMDMCMD];        /* hangup string */
    int fc;                    /* flow control */
    /* non-/etc/modems structure members */
    int connected;             /* 1 when connected, 0 otherwise */
    char bits;                 /* data bits (default '8') */
    char parity;               /* parity (default 'N') */
    char stop;                 /* stop bits (default '1') */
    int rings;                 /* Number of outgoing rings before stop call */
};

__BEGIN_DECLS

/*
 * extern declarations (exported functions and variables from libmodem.a)
 */

/* modems.c */
extern struct modems *getmdmnam(char *);
extern void setmdms(void);
extern struct modems *getnextmdm(void);
extern void setmdmdata(char, char, char, int);

/* line_manage.c */
extern int dial(char *);
extern int ldial(char *, char *);
extern int bdial(char *, int);
extern int bldial(char *, char *, int);
extern int open_mdm_line();
extern int lopen_mdm_line(char *);
extern int bopen_mdm_line(int);
extern int blopen_mdm_line(char *, int);
extern int close_nohangup(int);
extern int hangup(int);
extern struct modems *getopenmodem(void);
extern int hangup_nodev(int);
extern int clean_line(int, int);

extern struct modems *mdmopendevice;
extern int mdm_cycle;

/* mdmlock.c */
extern int mdm_lock(struct modems *);
extern int mdm_unlock(struct modems *);
extern int mdm_chklock(struct modems *);

/* mdmlog.c */
extern void mdm_log(int, char *, ...);
extern void open_mdm_log (void);
extern void close_mdm_log (void);

/* mdmalloc.c */
extern void *mdmalloc(size_t size);
extern void mdmfree(void *);

__END_DECLS

#endif /* _LM_MODEMS_H */
